==> watchdog_mailer-2.0.1.tar.gz: watchdog_mailer/src/Logger/WatchdogMailer.php <==
<?php

namespace Drupal\watchdog_mailer\Logger;

use Drupal\Component\Render\FormattableMarkup;
use Drupal\Component\Utility\Html;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Logger\RfcLoggerTrait;
use Drupal\Core\Logger\RfcLogLevel;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Psr\Log\LoggerInterface;

/**
 * {@inheritdoc}
 */
class WatchdogMailer implements LoggerInterface {
  use RfcLoggerTrait;
  use StringTranslationTrait;

  /**
   * The config factory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $config;

  /**
   * The language manager.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected $languageManager;

  /**
   * Constructs a new WatchdogMailer.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   A config factory for retrieving required config objects.
   * @param \Drupal\Core\Language\LanguageManagerInterface $language_manager
   *   The language manager.
   */
  public function __construct(ConfigFactoryInterface $config_factory, LanguageManagerInterface $language_manager) {
    $this->config = $config_factory->get('watchdog_mailer.settings');
    $this->languageManager = $language_manager;
  }

  /**
   * {@inheritdoc}
   */
  public function log($level, $message, array $context = []) {
    $enabled = $this->config->get('watchdog_mailer_enable');
    $channelsEnable = $this->config->get('channels_enable');
    $channelsNegate = $this->config->get('channels_negate');
    $channels = explode("\r\n", mb_strtolower($this->config->get('channels_list')));

    if ($channelsEnable && !empty($channels)) {
      if (
        !$channelsNegate && !in_array($context['channel'], $channels)
        ||
        $channelsNegate && in_array($context['channel'], $channels)
      ) {
        $enabled = 0;
      }
    }

    if ($enabled) {
      try {
        if ($level <= RfcLogLevel::WARNING || ($this->config->get('php_notices') && $context['channel'] == 'php')) {
          $body = new FormattableMarkup($message, $context);
          $body = Html::decodeEntities(strip_tags($body->__toString()));
          $params = [
            'subject' => $this->t('Error in the database log: @channel', ['@channel' => $context['channel']]),
            'body' => $body,
          ];
          $langcode = $this->languageManager->getCurrentLanguage()->getId();
          // @codingStandardsIgnoreLine
          if (!\Drupal::service('plugin.manager.mail')->mail(
            'watchdog_mailer',
            'watchdog_mailer',
            $this->config->get('mail_address'),
            $langcode,
            $params)
          ) {
            throw new Exception('There was a problem sending the message.');
          }
        }
      }
      catch (Exception $e) {
        // There can be no watchdog_exception to avoid a possible endless cycle.
        $this->notice($e->getMessage());
      }
    }
  }

}

==> watchdog_mailer-2.0.3.tar.gz: watchdog_mailer/src/Logger/WatchdogMailer.php <==
<?php

namespace Drupal\watchdog_mailer\Logger;

use Drupal\Component\Render\FormattableMarkup;
use Drupal\Component\Utility\Html;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Database\Connection;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Logger\RfcLoggerTrait;
use Drupal\Core\Logger\RfcLogLevel;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Psr\Log\LoggerInterface;

/**
 * {@inheritdoc}
 */
class WatchdogMailer implements LoggerInterface {
  use RfcLoggerTrait;
  use StringTranslationTrait;

  /**
   * The config factory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $config;

  /**
   * The language manager.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected $languageManager;

  /**
   * Drupal\Core\Database\Connection definition.
   *
   * @var \Drupal\Core\Database\Connection
   */
  private $connection;

  /**
   * Constructs a new WatchdogMailer.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   A config factory for retrieving required config objects.
   * @param \Drupal\Core\Language\LanguageManagerInterface $language_manager
   *   The language manager.
   * @param \Drupal\Core\Database\Connection $connection
   *   The database connection to run the query against.
   */
  public function __construct(ConfigFactoryInterface $config_factory, LanguageManagerInterface $language_manager, Connection $connection) {
    $this->config = $config_factory->get('watchdog_mailer.settings');
    $this->languageManager = $language_manager;
    $this->connection = $connection;
  }

  /**
   * {@inheritdoc}
   */
  public function log($level, $message, array $context = []) {
    $enabled = $this->config->get('watchdog_mailer_enable');
    $channelsEnable = $this->config->get('channels_enable');
    $channelsNegate = $this->config->get('channels_negate');
    $maxEmails = $this->config->get('max_emails_per_hour');
    $channels = explode("\r\n", mb_strtolower($this->config->get('channels_list')));

    if ($channelsEnable && !empty($channels)) {
      if (
        !$channelsNegate && !in_array($context['channel'], $channels)
        ||
        $channelsNegate && in_array($context['channel'], $channels)
      ) {
        $enabled = FALSE;
      }
    }

    if (!empty($maxEmails)) {
      $count = $this->connection->query("SELECT COUNT(*) FROM watchdog_mailer_history WHERE timestamp BETWEEN UNIX_TIMESTAMP(DATE_ADD(NOW(), INTERVAL -1 HOUR)) AND UNIX_TIMESTAMP()")->fetchField();
      if ($count >= $maxEmails) {
        $enabled = FALSE;
      }
    }

    if ($enabled) {
      try {
        if ($level <= RfcLogLevel::WARNING || ($this->config->get('php_notices') && $context['channel'] === 'php')) {
          $body = new FormattableMarkup($message, $context);
          $body = Html::decodeEntities(strip_tags($body->__toString()));
          $params = [
            'subject' => $this->t('Error in the database log: @channel', ['@channel' => $context['channel']]),
            'body' => $body,
          ];
          $langcode = $this->languageManager->getCurrentLanguage()->getId();
          // @codingStandardsIgnoreLine
          if (!\Drupal::service('plugin.manager.mail')->mail(
            'watchdog_mailer',
            'watchdog_mailer',
            $this->config->get('mail_address'),
            $langcode,
            $params)
          ) {
            throw new Exception('There was a problem sending the message.');
          }
          else {
            $this->connection->insert('watchdog_mailer_history')
              ->fields(['timestamp' => time()])
              ->execute();
          }
        }
      }
      catch (Exception $e) {
        // There can be no watchdog_exception to avoid a possible endless cycle.
        $this->notice($e->getMessage());
      }
    }
  }

}
